@@ -1,8 +1,6 @@
 #!/usr/bin/perl -c
 
 package MooseX::GlobRef::Object;
-use 5.006;
-our $VERSION = 0.02_03;
 
 =head1 NAME 
 
@@ -30,7 +28,7 @@ MooseX::GlobRef::Object - Store a Moose object in glob reference
     return readline $fh;
   }
 
-  my $io = new My::IO filename=>'/etc/passwd';
+  my $io = My::IO->new( filename=>'/etc/passwd' );
   print "::::::::::::::\n";
   print $io->filename, "\n";
   print "::::::::::::::\n";
@@ -41,20 +39,27 @@ MooseX::GlobRef::Object - Store a Moose object in glob reference
 
 This meta-policy allows to store Moose object in glob reference or file
 handle.  The class attributes will be stored in anonymous hash associated
-with glob reference.  It allows to create a Moose version of F<IO::Handle>.
+with glob reference.  It allows to create a Moose version of L<IO::Handle>.
 
-The elements of hash can be accessed with B<${*$self}-E<gt>{key}> expression.
+The elements of hash can be accessed with C<${*$self}-E<gt>{key}> expression.
 
 You can use L<MooseX::GlobRef::Meta::Instance> metaclass directly if you need
 more customised configuration.
 
 =cut
 
+use 5.006;
+use strict;
+use warnings;
 
-use metaclass 'MooseX::GlobRef::Meta::Class' =>
-    instance_metaclass => 'MooseX::GlobRef::Meta::Instance';
+our $VERSION = '0.03';
 
-use base 'Moose::Object';
+
+use metaclass 'MooseX::GlobRef::Meta::Class' => (
+    instance_metaclass => 'MooseX::GlobRef::Meta::Instance'
+);
+
+use parent 'Moose::Object';
 
 
 1;
@@ -87,7 +92,7 @@ Piotr Roszatycki E<lt>dexter@debian.orgE<gt>
 
 =head1 LICENSE
 
-Copyright (C) 2007 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
+Copyright (C) 2007, 2008 by Piotr Roszatycki E<lt>dexter@debian.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
